# baggianalysis

Baggianalysis is a library aimed at simplifying the analysis of particle-based simulations. It makes it easy to parse, convert and analyse trajectories generated by simulation codes in an agnostic way. It is written in C++ and provides Python bindings. It is modular and can be extended from C++ and Python.

The documentation can be found [here](https://lorenzo-rovigatti.github.io/baggianalysis/).

## Acknowledgements

* The [glm 0.9.9](https://glm.g-truc.net/0.9.9/index.html), [pybind 2.4.3](https://github.com/pybind/pybind11) and [spdlog 1.8.2](https://github.com/gabime/spdlog) libraries are included in the source tree.
* Natural sorting of files is carried out with the [NaturalSort](https://github.com/scopeInfinity/NaturalSort) library.
* [akuukka's quickhull](https://github.com/akuukka/quickhull) library is included in the source tree.
